---
title: <span class="badge object-type-scalar"></span> Knot
---
# <span class="badge object-type-scalar"></span> Knot

Velocity: knot (kn)

## Definition

```python
# Velocity: knot (kn)
Knot: typing.Literal["velocityknot"] = "velocityknot"
```
